"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.main = void 0;
const fast_glob_1 = __importDefault(require("fast-glob"));
const fs_1 = __importDefault(require("fs"));
const node_fetch_1 = __importDefault(require("node-fetch"));
const util_1 = require("util");
const convertToRerun_js_1 = require("../convertToRerun.js");
const writeFile = (0, util_1.promisify)(fs_1.default.writeFile);
const readFile = (0, util_1.promisify)(fs_1.default.readFile);
const query = `
query GetOrderedTests($organizationId: UUID!) {
  organization: organizationById(id: $organizationId) {
    tests: testsByOrganizationId(orderBy: [FAILURE_FREQUENCY_DESC, PATH_ASC]) {
      nodes {
        failureFrequency
        path
      }
    }
  }
}
`;
async function main() {
    if (process.env.ONE_REPORT_ORGANIZATION === undefined) {
        throw new Error('ONE_REPORT_ORGANIZATION is not set');
    }
    if (process.env.ONE_REPORT_URL === undefined) {
        throw new Error('ONE_REPORT_URL is not set');
    }
    if (process.env.ONE_REPORT_TOKEN === undefined) {
        throw new Error('ONE_REPORT_TOKEN is not set');
    }
    const variables = { organizationId: process.env.ONE_REPORT_ORGANIZATION };
    const url = new URL('/api/postgraphile/graphql', process.env.ONE_REPORT_URL);
    const res = await (0, node_fetch_1.default)(url.href, {
        method: 'POST',
        headers: {
            Authorization: `Bearer ${process.env.ONE_REPORT_TOKEN}`,
            'Content-Type': 'application/json',
        },
        body: JSON.stringify({ query, variables }),
    });
    if (!res.ok) {
        throw new Error(`${res.status} ${res.statusText}`);
    }
    const body = (await res.json());
    const gherkinPaths = await (0, fast_glob_1.default)(['features/**/*.feature']);
    const gherkinSources = await Promise.all(gherkinPaths.map((path) => readFile(path, 'utf8')));
    const parsedPaths = (0, convertToRerun_js_1.convertToRerun)(body.data, gherkinSources);
    const fileLocation = '@rerun.txt';
    await writeFile(fileLocation, parsedPaths.join('\n'));
    console.log(`You can now run the tests in prioritized order with the following command:
    cucumber-js --order rerun @rerun.txt`);
}
exports.main = main;
main().catch((err) => {
    console.error(err);
    process.exit(1);
});
//# sourceMappingURL=main.js.map