"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.convertToRerun = void 0;
const gherkin_utils_1 = require("@cucumber/gherkin-utils");
const parseGherkinDocument_js_1 = require("../src/parseGherkinDocument.js");
function convertToRerun(tcpResponse, gherkinSources) {
    let lineNumberByName = {};
    const parseResults = gherkinSources.map(parseGherkinDocument_js_1.parseGherkinDocument);
    for (const { gherkinDocument } of parseResults) {
        if (gherkinDocument) {
            lineNumberByName = buildLineNumberByName(gherkinDocument, lineNumberByName);
        }
    }
    const rerun = [];
    for (const { path } of tcpResponse.organization.tests.nodes) {
        const segments = path.split('/');
        const scenarioName = segments[segments.length - 1];
        const lineNumber = lineNumberByName[scenarioName];
        if (lineNumber) {
            rerun.push(`${segments.slice(0, segments.length - 1).join('/')}:${lineNumber}`);
        }
    }
    return rerun;
}
exports.convertToRerun = convertToRerun;
function buildLineNumberByName(gherkinDocument, lineNumberByName) {
    return (0, gherkin_utils_1.walkGherkinDocument)(gherkinDocument, lineNumberByName, {
        scenario(scenario, lineNumberByName) {
            return { ...lineNumberByName, [scenario.name]: scenario.location.line };
        },
    });
}
//# sourceMappingURL=convertToRerun.js.map