import { walkGherkinDocument } from '@cucumber/gherkin-utils';
import { parseGherkinDocument } from '../src/parseGherkinDocument.js';
export function convertToRerun(tcpResponse, gherkinSources) {
    let lineNumberByName = {};
    const parseResults = gherkinSources.map(parseGherkinDocument);
    for (const { gherkinDocument } of parseResults) {
        if (gherkinDocument) {
            lineNumberByName = buildLineNumberByName(gherkinDocument, lineNumberByName);
        }
    }
    const rerun = [];
    for (const { path } of tcpResponse.organization.tests.nodes) {
        const segments = path.split('/');
        const scenarioName = segments[segments.length - 1];
        const lineNumber = lineNumberByName[scenarioName];
        if (lineNumber) {
            rerun.push(`${segments.slice(0, segments.length - 1).join('/')}:${lineNumber}`);
        }
    }
    return rerun;
}
function buildLineNumberByName(gherkinDocument, lineNumberByName) {
    return walkGherkinDocument(gherkinDocument, lineNumberByName, {
        scenario(scenario, lineNumberByName) {
            return { ...lineNumberByName, [scenario.name]: scenario.location.line };
        },
    });
}
//# sourceMappingURL=convertToRerun.js.map